aboutsummaryrefslogtreecommitdiff
path: root/lib/cookie.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/cookie.h')
-rw-r--r--lib/cookie.h9
1 files changed, 4 insertions, 5 deletions
diff --git a/lib/cookie.h b/lib/cookie.h
index edb648c65..a3a54c717 100644
--- a/lib/cookie.h
+++ b/lib/cookie.h
@@ -40,8 +40,7 @@ struct Cookie {
char *domain; /* domain = <this> */
long expires; /* expires = <this> */
char *expirestr; /* the plain text version */
-
- char field1; /* read from a cookie file, 1 => FALSE, 2=> TRUE */
+ bool tailmatch; /* weather we do tail-matchning of the domain name */
/* RFC 2109 keywords. Version=1 means 2109-compliant cookie sending */
char *version; /* Version = <value> */
@@ -70,11 +69,11 @@ struct CookieInfo {
#define MAX_NAME_TXT "255"
/*
* Add a cookie to the internal list of cookies. The domain argument is only
* used if the header boolean is TRUE.
*/
struct Cookie *Curl_cookie_add(struct CookieInfo *, bool header, char *line,
- char *domain);
+ char *domain, char *path);
struct CookieInfo *Curl_cookie_init(char *, struct CookieInfo *, bool);
struct Cookie *Curl_cookie_getlist(struct CookieInfo *, char *, char *, bool);
@@ -70,11 +69,11 @@ struct CookieInfo {
#define MAX_NAME_TXT "255"
/*
- * Add a cookie to the internal list of cookies. The domain argument is only
- * used if the header boolean is TRUE.
+ * Add a cookie to the internal list of cookies. The domain and path arguments
+ * are only used if the header boolean is TRUE.
*/
struct Cookie *Curl_cookie_add(struct CookieInfo *, bool header, char *line,